###################################################################
#####  Create Project
###################################################################

create_project -force xilinx-zcu102-v2018.3 xilinx-zcu102-v2018.3 -part xczu9eg-ffvb1156-2-e

set_property board_part xilinx.com:zcu102:part0:3.2 [current_project]
create_bd_design "design_1"


###################################################################
#####  Add Zynq UltraScale+ MPSOC IP and apply Preset
###################################################################

create_bd_cell -type ip -vlnv xilinx.com:ip:zynq_ultra_ps_e zynq_ultra_ps_e_0
apply_bd_automation -rule xilinx.com:bd_rule:zynq_ultra_ps_e -config {apply_board_preset "1" }  [get_bd_cells zynq_ultra_ps_e_0]


###################################################################
#####  Modify PCW on PS
###################################################################

# Enable new AXI ports
set_property -dict [list CONFIG.PSU__USE__M_AXI_GP0 {1} CONFIG.PSU__USE__M_AXI_GP1 {0} CONFIG.PSU__USE__M_AXI_GP2 {1} CONFIG.PSU__USE__S_AXI_GP2 {1} CONFIG.PSU__USE__S_AXI_GP3 {1} CONFIG.PSU__USE__S_AXI_GP6 {1}] [get_bd_cells zynq_ultra_ps_e_0]

# Enable new clock (RPLL by default - shared with DP_AUDIO)
set_property -dict [list CONFIG.PSU__FPGA_PL1_ENABLE {1}] [get_bd_cells zynq_ultra_ps_e_0]

# Enable new reset
set_property -dict [list CONFIG.PSU__NUM_FABRIC_RESETS {2}] [get_bd_cells zynq_ultra_ps_e_0]

# Enable interrupts
set_property -dict [list CONFIG.PSU__USE__IRQ0 {1}] [get_bd_cells zynq_ultra_ps_e_0]

# Change QSPI to SPI1
set_property -dict [list CONFIG.PSU__QSPI__PERIPHERAL__ENABLE {0} CONFIG.PSU__SPI1__PERIPHERAL__ENABLE {1}] [get_bd_cells zynq_ultra_ps_e_0]

###################################################################
#####  RPU Slaves Hierarchy
###################################################################

# Hierarchical cell: RPU_SS_slaves
proc create_hier_cell_RPU_SS_slaves { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_RPU_SS_slaves() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_00
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_01
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 rpu_gpio

  # Create pins
  create_bd_pin -dir O -from 0 -to 0 rpu_led
  create_bd_pin -dir I -type rst resetn
  create_bd_pin -dir I -type clk clk

  # Create instance: axi_bram_ctrl_1, and set properties
  set axi_bram_ctrl_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl axi_bram_ctrl_1 ]

  # Create instance: axi_gpio_1, and set properties
  set axi_gpio_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_gpio axi_gpio_1 ]
  set_property -dict [ list \
   CONFIG.C_ALL_INPUTS {0} \
   CONFIG.C_ALL_OUTPUTS {1} \
   CONFIG.C_GPIO_WIDTH {1} \
   CONFIG.GPIO_BOARD_INTERFACE {Custom} \
   CONFIG.USE_BOARD_FLOW {true} \
 ] $axi_gpio_1

  # Create instance: blk_mem_gen_1, and set properties
  set blk_mem_gen_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:blk_mem_gen blk_mem_gen_1 ]
  set_property -dict [ list \
   CONFIG.EN_SAFETY_CKT {false} \
   CONFIG.Enable_B {Use_ENB_Pin} \
   CONFIG.Memory_Type {True_Dual_Port_RAM} \
   CONFIG.Port_B_Clock {100} \
   CONFIG.Port_B_Enable_Rate {100} \
   CONFIG.Port_B_Write_Rate {50} \
   CONFIG.Use_RSTB_Pin {true} \
 ] $blk_mem_gen_1

  # Create instance: c_counter_binary_1, and set properties
  set c_counter_binary_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:c_counter_binary c_counter_binary_1 ]
  set_property -dict [ list \
   CONFIG.CE {true} \
   CONFIG.Output_Width {26} \
 ] $c_counter_binary_1

  # Create instance: util_vector_logic_0, and set properties
  set util_vector_logic_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_0 ]
  set_property -dict [ list \
   CONFIG.C_OPERATION {and} \
   CONFIG.C_SIZE {1} \
   CONFIG.LOGO_FILE {data/sym_andgate.png} \
 ] $util_vector_logic_0

  # Create instance: xlconstant_2, and set properties
  set xlconstant_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant xlconstant_2 ]

  # Create instance: xlslice_2, and set properties
  set xlslice_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_2 ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {25} \
   CONFIG.DIN_TO {25} \
   CONFIG.DIN_WIDTH {26} \
   CONFIG.DOUT_WIDTH {1} \
 ] $xlslice_2

  # Create interface connections
  connect_bd_intf_net -intf_net rpu_gpio [get_bd_intf_pins rpu_gpio] [get_bd_intf_pins axi_gpio_1/GPIO]
  connect_bd_intf_net -intf_net axi_bram_ctrl_1_BRAM_PORTA [get_bd_intf_pins axi_bram_ctrl_1/BRAM_PORTA] [get_bd_intf_pins blk_mem_gen_1/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_bram_ctrl_1_BRAM_PORTB [get_bd_intf_pins axi_bram_ctrl_1/BRAM_PORTB] [get_bd_intf_pins blk_mem_gen_1/BRAM_PORTB]
  connect_bd_intf_net -intf_net S00_AXI [get_bd_intf_pins S_AXI_00] [get_bd_intf_pins axi_bram_ctrl_1/S_AXI]
  connect_bd_intf_net -intf_net S01_AXI [get_bd_intf_pins S_AXI_01] [get_bd_intf_pins axi_gpio_1/S_AXI]

  # Create port connections
  connect_bd_net -net c_counter_binary_1_Q [get_bd_pins c_counter_binary_1/Q] [get_bd_pins xlslice_2/Din]
  connect_bd_net -net util_vector_logic_0_Res [get_bd_pins c_counter_binary_1/CE] [get_bd_pins util_vector_logic_0/Res]
  connect_bd_net -net xlconstant_2_dout [get_bd_pins util_vector_logic_0/Op2] [get_bd_pins xlconstant_2/dout]
  connect_bd_net -net rpu_led [get_bd_pins rpu_led] [get_bd_pins xlslice_2/Dout]

  connect_bd_net -net clk [get_bd_pins clk] [get_bd_pins axi_bram_ctrl_1/s_axi_aclk] [get_bd_pins axi_gpio_1/s_axi_aclk] [get_bd_pins c_counter_binary_1/CLK]
  connect_bd_net -net resetn [get_bd_pins resetn] [get_bd_pins axi_bram_ctrl_1/s_axi_aresetn] [get_bd_pins axi_gpio_1/s_axi_aresetn] [get_bd_pins util_vector_logic_0/Op1]

  # Restore current instance
  current_bd_instance $oldCurInst
}

###################################################################
#####  RPU Masters Hierarchy
###################################################################

# Hierarchical cell: RPU_SS_masters
proc create_hier_cell_RPU_SS_masters { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_RPU_SS_masters() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_CTL_FW
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_LITE_DMA

  # Create pins
  create_bd_pin -dir I -type rst intcon_resetn
  create_bd_pin -dir I -type rst periph_resetn
  create_bd_pin -dir O -type intr mm2s_introut
  create_bd_pin -dir O -type intr s2mm_introut
  create_bd_pin -dir I -type clk clk

  # Create instance: axi_dma_1, and set properties
  set axi_dma_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dma axi_dma_1 ]
  set_property -dict [ list \
   CONFIG.c_include_sg {1} \
   CONFIG.c_sg_include_stscntrl_strm {0} \
   CONFIG.c_include_mm2s_dre {1} \
   CONFIG.c_include_s2mm_dre {1} \
   CONFIG.c_m_axis_mm2s_tdata_width {32} \
   CONFIG.c_addr_width {40} \
 ] $axi_dma_1

  # Create instance: axi_firewall_0, and set properties
  set axi_firewall_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_firewall axi_firewall_0 ]

  # Create instance: axi_interconnect_rpu_m, and set properties
  set axi_interconnect_rpu_m [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_interconnect_rpu_m ]
  set_property -dict [ list \
   CONFIG.NUM_MI {1} \
   CONFIG.NUM_SI {3} \
 ] $axi_interconnect_rpu_m

  # Create interface connections
  connect_bd_intf_net -intf_net axi_dma_0_M_AXIS_MM2S [get_bd_intf_pins axi_dma_1/M_AXIS_MM2S] [get_bd_intf_pins axi_dma_1/S_AXIS_S2MM]
  connect_bd_intf_net -intf_net axi_dma_0_M_AXI_MM2S [get_bd_intf_pins axi_dma_1/M_AXI_MM2S] [get_bd_intf_pins axi_interconnect_rpu_m/S00_AXI]
  connect_bd_intf_net -intf_net axi_dma_0_M_AXI_S2MM [get_bd_intf_pins axi_dma_1/M_AXI_S2MM] [get_bd_intf_pins axi_interconnect_rpu_m/S01_AXI]
  connect_bd_intf_net -intf_net axi_dma_1_M_AXI_SG [get_bd_intf_pins axi_dma_1/M_AXI_SG] [get_bd_intf_pins axi_interconnect_rpu_m/S02_AXI]
  connect_bd_intf_net -intf_net axi_firewall_0_M_AXI [get_bd_intf_pins M_AXI] [get_bd_intf_pins axi_firewall_0/M_AXI]
  connect_bd_intf_net -intf_net S_AXI_CTL [get_bd_intf_pins S_AXI_CTL_FW] [get_bd_intf_pins axi_firewall_0/S_AXI_CTL]
  connect_bd_intf_net -intf_net S_AXI_LITE [get_bd_intf_pins S_AXI_LITE_DMA] [get_bd_intf_pins axi_dma_1/S_AXI_LITE]
  connect_bd_intf_net -intf_net axi_interconnect_rpu_m_M00_AXI [get_bd_intf_pins axi_firewall_0/S_AXI] [get_bd_intf_pins axi_interconnect_rpu_m/M00_AXI]

  # Create port connections
  connect_bd_net -net intcon_resetn [get_bd_pins intcon_resetn] [get_bd_pins axi_interconnect_rpu_m/ARESETN]
  connect_bd_net -net clk [get_bd_pins clk] [get_bd_pins axi_dma_1/m_axi_mm2s_aclk] [get_bd_pins axi_dma_1/m_axi_s2mm_aclk] [get_bd_pins axi_dma_1/m_axi_sg_aclk] [get_bd_pins axi_dma_1/s_axi_lite_aclk] [get_bd_pins axi_firewall_0/aclk] [get_bd_pins axi_interconnect_rpu_m/ACLK] [get_bd_pins axi_interconnect_rpu_m/M00_ACLK] [get_bd_pins axi_interconnect_rpu_m/S00_ACLK] [get_bd_pins axi_interconnect_rpu_m/S01_ACLK] [get_bd_pins axi_interconnect_rpu_m/S02_ACLK]
  connect_bd_net -net periph_resetn [get_bd_pins periph_resetn] [get_bd_pins axi_dma_1/axi_resetn] [get_bd_pins axi_firewall_0/aresetn] [get_bd_pins axi_interconnect_rpu_m/M00_ARESETN] [get_bd_pins axi_interconnect_rpu_m/S00_ARESETN] [get_bd_pins axi_interconnect_rpu_m/S01_ARESETN] [get_bd_pins axi_interconnect_rpu_m/S02_ARESETN]
  connect_bd_net -net axi_dma_1_mm2s_introut [get_bd_pins mm2s_introut] [get_bd_pins axi_dma_1/mm2s_introut]
  connect_bd_net -net axi_dma_1_s2mm_introut [get_bd_pins s2mm_introut] [get_bd_pins axi_dma_1/s2mm_introut]

  # Restore current instance
  current_bd_instance $oldCurInst
}

###################################################################
#####  APU Slaves Hierarchy
###################################################################

# Hierarchical cell: APU_SS_slaves
proc create_hier_cell_APU_SS_slaves { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_APU_SS_slaves() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_00
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_01
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 apu_gpio

  # Create pins
  create_bd_pin -dir O -from 0 -to 0 apu_led
  create_bd_pin -dir I -type clk clk
  create_bd_pin -dir I -type rst periph_resetn

  # Create instance: axi_bram_ctrl_0, and set properties
  set axi_bram_ctrl_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl axi_bram_ctrl_0 ]

  # Create instance: axi_gpio_0, and set properties
  set axi_gpio_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_gpio axi_gpio_0 ]
  set_property -dict [ list \
   CONFIG.C_ALL_INPUTS {0} \
   CONFIG.C_ALL_OUTPUTS {1} \
   CONFIG.C_GPIO_WIDTH {2} \
   CONFIG.GPIO_BOARD_INTERFACE {Custom} \
   CONFIG.USE_BOARD_FLOW {true} \
 ] $axi_gpio_0

  # Create instance: blk_mem_gen_0, and set properties
  set blk_mem_gen_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:blk_mem_gen blk_mem_gen_0 ]
  set_property -dict [ list \
   CONFIG.EN_SAFETY_CKT {false} \
   CONFIG.Enable_B {Use_ENB_Pin} \
   CONFIG.Memory_Type {True_Dual_Port_RAM} \
   CONFIG.Port_B_Clock {100} \
   CONFIG.Port_B_Enable_Rate {100} \
   CONFIG.Port_B_Write_Rate {50} \
   CONFIG.Use_RSTB_Pin {true} \
 ] $blk_mem_gen_0

  # Create instance: c_counter_binary_1, and set properties
  set c_counter_binary_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:c_counter_binary c_counter_binary_1 ]
  set_property -dict [ list \
   CONFIG.CE {true} \
   CONFIG.Output_Width {26} \
 ] $c_counter_binary_1

  # Create instance: util_vector_logic_0, and set properties
  set util_vector_logic_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic util_vector_logic_0 ]
  set_property -dict [ list \
   CONFIG.C_OPERATION {and} \
   CONFIG.C_SIZE {1} \
   CONFIG.LOGO_FILE {data/sym_andgate.png} \
 ] $util_vector_logic_0

  # Create instance: xlconstant_2, and set properties
  set xlconstant_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant xlconstant_2 ]

  # Create instance: xlslice_2, and set properties
  set xlslice_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_2 ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {25} \
   CONFIG.DIN_TO {25} \
   CONFIG.DIN_WIDTH {26} \
   CONFIG.DOUT_WIDTH {1} \
 ] $xlslice_2

  # Create interface connections
  connect_bd_intf_net -intf_net axi_bram_ctrl_0_BRAM_PORTA [get_bd_intf_pins axi_bram_ctrl_0/BRAM_PORTA] [get_bd_intf_pins blk_mem_gen_0/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_bram_ctrl_0_BRAM_PORTB [get_bd_intf_pins axi_bram_ctrl_0/BRAM_PORTB] [get_bd_intf_pins blk_mem_gen_0/BRAM_PORTB]
  connect_bd_intf_net -intf_net apu_gpio [get_bd_intf_pins apu_gpio] [get_bd_intf_pins axi_gpio_0/GPIO]
  connect_bd_intf_net -intf_net S00_AXI [get_bd_intf_pins S_AXI_00] [get_bd_intf_pins axi_bram_ctrl_0/S_AXI]
  connect_bd_intf_net -intf_net S01_AXI [get_bd_intf_pins S_AXI_01] [get_bd_intf_pins axi_gpio_0/S_AXI]

  # Create port connections
  connect_bd_net -net c_counter_binary_1_Q [get_bd_pins c_counter_binary_1/Q] [get_bd_pins xlslice_2/Din]
  connect_bd_net -net periph_resetn [get_bd_pins periph_resetn] [get_bd_pins axi_bram_ctrl_0/s_axi_aresetn] [get_bd_pins axi_gpio_0/s_axi_aresetn] [get_bd_pins util_vector_logic_0/Op1]
  connect_bd_net -net util_vector_logic_0_Res [get_bd_pins c_counter_binary_1/CE] [get_bd_pins util_vector_logic_0/Res]
  connect_bd_net -net xlconstant_2_dout [get_bd_pins util_vector_logic_0/Op2] [get_bd_pins xlconstant_2/dout]
  connect_bd_net -net apu_led [get_bd_pins apu_led] [get_bd_pins xlslice_2/Dout]
  connect_bd_net -net zynq_ultra_ps_e_0_pl_clk0 [get_bd_pins clk] [get_bd_pins axi_bram_ctrl_0/s_axi_aclk] [get_bd_pins axi_gpio_0/s_axi_aclk] [get_bd_pins c_counter_binary_1/CLK]

  # Restore current instance
  current_bd_instance $oldCurInst
}

###################################################################
#####  APU Masters Hierarchy
###################################################################

# Hierarchical cell: APU_SS_masters
proc create_hier_cell_APU_SS_masters { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_APU_SS_masters() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI_FW0
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI_FW1
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_CTL_FW0
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_CTL_FW1
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_LITE_DMA
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_LITE_CDMA

  # Create pins
  create_bd_pin -dir I -type rst intcon_resetn
  create_bd_pin -dir I -type rst periph_resetn
  create_bd_pin -dir O -type intr cdma_introut
  create_bd_pin -dir O -type intr mm2s_introut
  create_bd_pin -dir O -type intr s2mm_introut
  create_bd_pin -dir I -type clk clk

  # Create instance: axi_cdma_0, and set properties
  set axi_cdma_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_cdma axi_cdma_0 ]
  set_property -dict [ list \
   CONFIG.C_INCLUDE_SG {1} \
   CONFIG.C_ADDR_WIDTH {40} \
 ] $axi_cdma_0

  # Create instance: axi_dma_0, and set properties
  set axi_dma_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dma axi_dma_0 ]
  set_property -dict [ list \
   CONFIG.c_include_s2mm {1} \
   CONFIG.c_include_sg {1} \
   CONFIG.c_m_axis_mm2s_tdata_width {32} \
   CONFIG.c_s2mm_burst_size {16} \
   CONFIG.c_sg_include_stscntrl_strm {0} \
   CONFIG.c_include_mm2s_dre {1} \
   CONFIG.c_include_s2mm_dre {1} \
   CONFIG.c_addr_width {40} \
 ] $axi_dma_0

  # Create instance: axi_firewall_0, and set properties
  set axi_firewall_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_firewall axi_firewall_0 ]

  # Create instance: axi_firewall_1, and set properties
  set axi_firewall_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_firewall axi_firewall_1 ]

  # Create instance: axi_interconnect_cdma, and set properties
  set axi_interconnect_cdma [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_interconnect_cdma ]
  set_property -dict [ list \
   CONFIG.ENABLE_ADVANCED_OPTIONS {1} \
   CONFIG.NUM_MI {1} \
   CONFIG.NUM_SI {2} \
 ] $axi_interconnect_cdma

  # Create instance: axi_interconnect_dma, and set properties
  set axi_interconnect_dma [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_interconnect_dma ]
  set_property -dict [ list \
   CONFIG.ENABLE_ADVANCED_OPTIONS {1} \
   CONFIG.NUM_MI {1} \
   CONFIG.NUM_SI {3} \
 ] $axi_interconnect_dma

  # Create interface connections
  connect_bd_intf_net -intf_net M_AXI_FW1 [get_bd_intf_pins M_AXI_FW1] [get_bd_intf_pins axi_firewall_1/M_AXI]
  connect_bd_intf_net -intf_net S01_AXI [get_bd_intf_pins axi_dma_0/M_AXI_S2MM] [get_bd_intf_pins axi_interconnect_dma/S01_AXI]
  connect_bd_intf_net -intf_net axi_cdma_0_M_AXI [get_bd_intf_pins axi_cdma_0/M_AXI] [get_bd_intf_pins axi_interconnect_cdma/S00_AXI]
  connect_bd_intf_net -intf_net axi_cdma_0_M_AXI_SG [get_bd_intf_pins axi_cdma_0/M_AXI_SG] [get_bd_intf_pins axi_interconnect_cdma/S01_AXI]
  connect_bd_intf_net -intf_net axi_dma_0_M_AXIS_MM2S [get_bd_intf_pins axi_dma_0/M_AXIS_MM2S] [get_bd_intf_pins axi_dma_0/S_AXIS_S2MM]
  connect_bd_intf_net -intf_net axi_dma_0_M_AXI_MM2S [get_bd_intf_pins axi_dma_0/M_AXI_MM2S] [get_bd_intf_pins axi_interconnect_dma/S00_AXI]
  connect_bd_intf_net -intf_net axi_dma_0_M_AXI_SG [get_bd_intf_pins axi_dma_0/M_AXI_SG] [get_bd_intf_pins axi_interconnect_dma/S02_AXI]
  connect_bd_intf_net -intf_net axi_firewall_0_M_AXI [get_bd_intf_pins M_AXI_FW0] [get_bd_intf_pins axi_firewall_0/M_AXI]
  connect_bd_intf_net -intf_net S_AXI_LITE_DMA [get_bd_intf_pins S_AXI_LITE_DMA] [get_bd_intf_pins axi_dma_0/S_AXI_LITE]
  connect_bd_intf_net -intf_net S_AXI_LITE_CDMA [get_bd_intf_pins S_AXI_LITE_CDMA] [get_bd_intf_pins axi_cdma_0/S_AXI_LITE]
  connect_bd_intf_net -intf_net S_AXI_CTL_FW0 [get_bd_intf_pins S_AXI_CTL_FW0] [get_bd_intf_pins axi_firewall_0/S_AXI_CTL]
  connect_bd_intf_net -intf_net S_AXI_CTL_FW1 [get_bd_intf_pins S_AXI_CTL_FW1] [get_bd_intf_pins axi_firewall_1/S_AXI_CTL]
  connect_bd_intf_net -intf_net axi_interconnect_cdma_M00_AXI [get_bd_intf_pins axi_firewall_0/S_AXI] [get_bd_intf_pins axi_interconnect_cdma/M00_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_dma_M00_AXI [get_bd_intf_pins axi_firewall_1/S_AXI] [get_bd_intf_pins axi_interconnect_dma/M00_AXI]

  # Create port connections
  connect_bd_net -net axi_cdma_0_cdma_introut [get_bd_pins cdma_introut] [get_bd_pins axi_cdma_0/cdma_introut]
  connect_bd_net -net axi_dma_0_mm2s_introut [get_bd_pins mm2s_introut] [get_bd_pins axi_dma_0/mm2s_introut]
  connect_bd_net -net axi_dma_0_s2mm_introut [get_bd_pins s2mm_introut] [get_bd_pins axi_dma_0/s2mm_introut]
  connect_bd_net -net periph_resetn [get_bd_pins periph_resetn] [get_bd_pins axi_cdma_0/s_axi_lite_aresetn] [get_bd_pins axi_dma_0/axi_resetn] [get_bd_pins axi_interconnect_cdma/M00_ARESETN] [get_bd_pins axi_interconnect_cdma/S00_ARESETN] [get_bd_pins axi_interconnect_cdma/S01_ARESETN] [get_bd_pins axi_interconnect_dma/M00_ARESETN] [get_bd_pins axi_interconnect_dma/S00_ARESETN] [get_bd_pins axi_interconnect_dma/S01_ARESETN] [get_bd_pins axi_interconnect_dma/S02_ARESETN]
  connect_bd_net -net intcon_resetn [get_bd_pins intcon_resetn] [get_bd_pins axi_firewall_0/aresetn] [get_bd_pins axi_firewall_1/aresetn] [get_bd_pins axi_interconnect_cdma/ARESETN] [get_bd_pins axi_interconnect_dma/ARESETN]
  connect_bd_net -net clk [get_bd_pins clk] [get_bd_pins axi_cdma_0/m_axi_aclk] [get_bd_pins axi_cdma_0/s_axi_lite_aclk] [get_bd_pins axi_dma_0/m_axi_mm2s_aclk] [get_bd_pins axi_dma_0/m_axi_s2mm_aclk] [get_bd_pins axi_dma_0/s_axi_lite_aclk] [get_bd_pins axi_firewall_0/aclk] [get_bd_pins axi_firewall_1/aclk] [get_bd_pins axi_interconnect_cdma/ACLK] [get_bd_pins axi_interconnect_cdma/M00_ACLK] [get_bd_pins axi_interconnect_cdma/S00_ACLK] [get_bd_pins axi_interconnect_cdma/S01_ACLK] [get_bd_pins axi_interconnect_dma/ACLK] [get_bd_pins axi_interconnect_dma/M00_ACLK] [get_bd_pins axi_interconnect_dma/S00_ACLK] [get_bd_pins axi_interconnect_dma/S01_ACLK] [get_bd_pins axi_interconnect_dma/S02_ACLK] [get_bd_pins axi_dma_0/m_axi_sg_aclk]

  # Restore current instance
  current_bd_instance $oldCurInst
}

###################################################################
#####  RPU Top Level
###################################################################

# Hierarchical cell: RPU_SS
proc create_hier_cell_RPU_SS { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_RPU_SS() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S00_AXI
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 rpu_gpio

  # Create pins
  create_bd_pin -dir O -from 0 -to 0 rpu_led
  create_bd_pin -dir I -type rst pl_resetn
  create_bd_pin -dir O -type intr mm2s_introut
  create_bd_pin -dir O -type intr s2mm_introut
  create_bd_pin -dir I -type clk clk

  # Create instance: RPU_SS_masters
  create_hier_cell_RPU_SS_masters $hier_obj RPU_SS_masters

  # Create instance: RPU_SS_slaves
  create_hier_cell_RPU_SS_slaves $hier_obj RPU_SS_slaves

  # Create instance: axi_interconnect_rpu, and set properties
  set axi_interconnect_rpu [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_interconnect_rpu ]
  set_property -dict [ list \
   CONFIG.NUM_MI {4} \
 ] $axi_interconnect_rpu

  # Create instance: proc_sys_reset_rpu, and set properties
  set proc_sys_reset_rpu [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset proc_sys_reset_rpu ]

  # Create instance: xlconstant_3, and set properties
  set xlconstant_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant xlconstant_3 ]

  # Create interface connections
  connect_bd_intf_net -intf_net rpu_gpio [get_bd_intf_pins rpu_gpio] [get_bd_intf_pins RPU_SS_slaves/rpu_gpio]
  connect_bd_intf_net -intf_net axi_firewall_1_M_AXI [get_bd_intf_pins M_AXI] [get_bd_intf_pins RPU_SS_masters/M_AXI]
  connect_bd_intf_net -intf_net RPU_SS_slaves_S_AXI_00 [get_bd_intf_pins RPU_SS_slaves/S_AXI_00] [get_bd_intf_pins axi_interconnect_rpu/M00_AXI]
  connect_bd_intf_net -intf_net RPU_SS_masters_S_AXI_CTL [get_bd_intf_pins RPU_SS_masters/S_AXI_CTL_FW] [get_bd_intf_pins axi_interconnect_rpu/M02_AXI]
  connect_bd_intf_net -intf_net RPU_SS_masters_S_AXI_LITE [get_bd_intf_pins RPU_SS_masters/S_AXI_LITE_DMA] [get_bd_intf_pins axi_interconnect_rpu/M03_AXI]
  connect_bd_intf_net -intf_net RPU_SS_slaves_S_AXI_01 [get_bd_intf_pins RPU_SS_slaves/S_AXI_01] [get_bd_intf_pins axi_interconnect_rpu/M01_AXI]
  connect_bd_intf_net -intf_net zynq_ultra_ps_e_0_M_AXI_HPM0_LPD [get_bd_intf_pins S00_AXI] [get_bd_intf_pins axi_interconnect_rpu/S00_AXI]

  # Create port connections
  connect_bd_net -net RPU_SS_slaves_rpu_led [get_bd_pins rpu_led] [get_bd_pins RPU_SS_slaves/rpu_led]
  connect_bd_net -net intcon_resetn [get_bd_pins RPU_SS_masters/intcon_resetn] [get_bd_pins axi_interconnect_rpu/ARESETN] [get_bd_pins proc_sys_reset_rpu/interconnect_aresetn]
  connect_bd_net -net clk [get_bd_pins clk] [get_bd_pins RPU_SS_masters/clk] [get_bd_pins RPU_SS_slaves/clk] [get_bd_pins axi_interconnect_rpu/ACLK] [get_bd_pins axi_interconnect_rpu/M00_ACLK] [get_bd_pins axi_interconnect_rpu/M01_ACLK] [get_bd_pins axi_interconnect_rpu/M02_ACLK] [get_bd_pins axi_interconnect_rpu/M03_ACLK] [get_bd_pins axi_interconnect_rpu/S00_ACLK] [get_bd_pins proc_sys_reset_rpu/slowest_sync_clk]
  connect_bd_net -net periph_resetn [get_bd_pins RPU_SS_masters/periph_resetn] [get_bd_pins RPU_SS_slaves/resetn] [get_bd_pins axi_interconnect_rpu/M00_ARESETN] [get_bd_pins axi_interconnect_rpu/M01_ARESETN] [get_bd_pins axi_interconnect_rpu/M02_ARESETN] [get_bd_pins axi_interconnect_rpu/M03_ARESETN] [get_bd_pins axi_interconnect_rpu/S00_ARESETN] [get_bd_pins proc_sys_reset_rpu/peripheral_aresetn]
  connect_bd_net -net axi_dma_1_mm2s_introut [get_bd_pins mm2s_introut] [get_bd_pins RPU_SS_masters/mm2s_introut]
  connect_bd_net -net axi_dma_1_s2mm_introut [get_bd_pins s2mm_introut] [get_bd_pins RPU_SS_masters/s2mm_introut]
  connect_bd_net -net xlconstant_3_dout [get_bd_pins proc_sys_reset_rpu/dcm_locked] [get_bd_pins xlconstant_3/dout]
  connect_bd_net -net zynq_ultra_ps_e_0_pl_resetn1 [get_bd_pins pl_resetn] [get_bd_pins proc_sys_reset_rpu/ext_reset_in]

  # Restore current instance
  current_bd_instance $oldCurInst
}

###################################################################
#####  APU Top Level
###################################################################

# Hierarchical cell: APU_SS
proc create_hier_cell_APU_SS { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_APU_SS() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI_FW0
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI_FW1
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S00_AXI
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 apu_gpio

  # Create pins
  create_bd_pin -dir O -type intr cdma_introut
  create_bd_pin -dir I -type rst pl_resetn
  create_bd_pin -dir O -type intr mm2s_introut
  create_bd_pin -dir O -from 0 -to 0 apu_led
  create_bd_pin -dir O -type intr s2mm_introut
  create_bd_pin -dir I -type clk clk

  # Create instance: APU_SS_masters
  create_hier_cell_APU_SS_masters $hier_obj APU_SS_masters

  # Create instance: APU_SS_slaves
  create_hier_cell_APU_SS_slaves $hier_obj APU_SS_slaves

  # Create instance: axi_interconnect_apu, and set properties
  set axi_interconnect_apu [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_interconnect_apu ]
  set_property -dict [ list \
   CONFIG.NUM_MI {6} \
   CONFIG.NUM_SI {1} \
 ] $axi_interconnect_apu

  # Create instance: proc_sys_reset_apu, and set properties
  set proc_sys_reset_apu [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset proc_sys_reset_apu ]

  # Create instance: xlconstant_1, and set properties
  set xlconstant_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant xlconstant_1 ]

  # Create interface connections
  connect_bd_intf_net -intf_net M_AXI_FW1 [get_bd_intf_pins M_AXI_FW1] [get_bd_intf_pins APU_SS_masters/M_AXI_FW1]
  connect_bd_intf_net -intf_net S00_AXI [get_bd_intf_pins S00_AXI] [get_bd_intf_pins axi_interconnect_apu/S00_AXI]
  connect_bd_intf_net -intf_net axi_firewall_0_M_AXI [get_bd_intf_pins M_AXI_FW0] [get_bd_intf_pins APU_SS_masters/M_AXI_FW0]
  connect_bd_intf_net -intf_net axi_gpio_0_GPIO [get_bd_intf_pins apu_gpio] [get_bd_intf_pins APU_SS_slaves/apu_gpio]
  connect_bd_intf_net -intf_net APU_SS_slaves_S_AXI_00 [get_bd_intf_pins APU_SS_slaves/S_AXI_00] [get_bd_intf_pins axi_interconnect_apu/M00_AXI]
  connect_bd_intf_net -intf_net APU_SS_slaves_S_AXI_01 [get_bd_intf_pins APU_SS_slaves/S_AXI_01] [get_bd_intf_pins axi_interconnect_apu/M01_AXI]
  connect_bd_intf_net -intf_net APU_SS_masters_S_AXI_LITE_DMA [get_bd_intf_pins APU_SS_masters/S_AXI_LITE_DMA] [get_bd_intf_pins axi_interconnect_apu/M02_AXI]
  connect_bd_intf_net -intf_net APU_SS_masters_S_AXI_LITE_CDMA [get_bd_intf_pins APU_SS_masters/S_AXI_LITE_CDMA] [get_bd_intf_pins axi_interconnect_apu/M03_AXI]
  connect_bd_intf_net -intf_net APU_SS_masters_S_AXI_CTL_FW0 [get_bd_intf_pins APU_SS_masters/S_AXI_CTL_FW0] [get_bd_intf_pins axi_interconnect_apu/M04_AXI]
  connect_bd_intf_net -intf_net APU_SS_masters_S_AXI_CTL_FW1 [get_bd_intf_pins APU_SS_masters/S_AXI_CTL_FW1] [get_bd_intf_pins axi_interconnect_apu/M05_AXI]

  # Create port connections
  connect_bd_net -net APU_SS_slaves_apu_led [get_bd_pins apu_led] [get_bd_pins APU_SS_slaves/apu_led]
  connect_bd_net -net axi_cdma_0_cdma_introut [get_bd_pins cdma_introut] [get_bd_pins APU_SS_masters/cdma_introut]
  connect_bd_net -net axi_dma_0_mm2s_introut [get_bd_pins mm2s_introut] [get_bd_pins APU_SS_masters/mm2s_introut]
  connect_bd_net -net axi_dma_0_s2mm_introut [get_bd_pins s2mm_introut] [get_bd_pins APU_SS_masters/s2mm_introut]
  connect_bd_net -net proc_sys_reset_0_peripheral_aresetn [get_bd_pins APU_SS_masters/periph_resetn] [get_bd_pins APU_SS_slaves/periph_resetn] [get_bd_pins axi_interconnect_apu/M00_ARESETN] [get_bd_pins axi_interconnect_apu/M01_ARESETN] [get_bd_pins axi_interconnect_apu/M02_ARESETN] [get_bd_pins axi_interconnect_apu/M03_ARESETN] [get_bd_pins axi_interconnect_apu/M04_ARESETN] [get_bd_pins axi_interconnect_apu/M05_ARESETN] [get_bd_pins axi_interconnect_apu/S00_ARESETN] [get_bd_pins proc_sys_reset_apu/peripheral_aresetn]
  connect_bd_net -net proc_sys_reset_1_interconnect_aresetn [get_bd_pins APU_SS_masters/intcon_resetn] [get_bd_pins axi_interconnect_apu/ARESETN] [get_bd_pins proc_sys_reset_apu/interconnect_aresetn]
  connect_bd_net -net xlconstant_1_dout [get_bd_pins proc_sys_reset_apu/dcm_locked] [get_bd_pins xlconstant_1/dout]
  connect_bd_net -net pl_clk [get_bd_pins clk] [get_bd_pins APU_SS_masters/clk] [get_bd_pins APU_SS_slaves/clk] [get_bd_pins axi_interconnect_apu/ACLK] [get_bd_pins axi_interconnect_apu/M00_ACLK] [get_bd_pins axi_interconnect_apu/M01_ACLK] [get_bd_pins axi_interconnect_apu/M02_ACLK] [get_bd_pins axi_interconnect_apu/M03_ACLK] [get_bd_pins axi_interconnect_apu/M04_ACLK] [get_bd_pins axi_interconnect_apu/M05_ACLK] [get_bd_pins axi_interconnect_apu/S00_ACLK] [get_bd_pins proc_sys_reset_apu/slowest_sync_clk]
  connect_bd_net -net pl_resetn [get_bd_pins pl_resetn] [get_bd_pins proc_sys_reset_apu/ext_reset_in]

  # Restore current instance
  current_bd_instance $oldCurInst
}



###################################################################
#####  PL Subsystem Hierarchy
###################################################################
# Hierarchical cell: PL_SS
proc create_hier_cell_PL_SS { parentCell nameHier } {

  variable script_folder

  if { $parentCell eq "" || $nameHier eq "" } {
     catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_PL_SS() - Empty argument(s)!"}
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:diff_clock_rtl:1.0 CLK_IN

  # Create pins
  create_bd_pin -dir O -from 0 -to 0 PL_LED
  create_bd_pin -dir O -from 4 -to 0 irq
  create_bd_pin -dir I int0
  create_bd_pin -dir I int1
  create_bd_pin -dir I int2
  create_bd_pin -dir I int3
  create_bd_pin -dir I int4


  # Create instance: c_counter_binary_0, and set properties
  set c_counter_binary_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:c_counter_binary c_counter_binary_0 ]
  set_property -dict [ list \
   CONFIG.CE {true} \
   CONFIG.Output_Width {26} \
 ] $c_counter_binary_0

  # Create instance: clk_wiz_0, and set properties
  set clk_wiz_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz clk_wiz_0 ]
  set_property -dict [ list \
   CONFIG.CLKIN1_JITTER_PS {33.330000000000005} \
   CONFIG.CLKOUT1_JITTER {101.475} \
   CONFIG.CLKOUT1_PHASE_ERROR {77.836} \
   CONFIG.CLK_IN1_BOARD_INTERFACE {user_si570_sysclk} \
   CONFIG.MMCM_CLKFBOUT_MULT_F {4.000} \
   CONFIG.MMCM_CLKIN1_PERIOD {3.333} \
   CONFIG.MMCM_CLKIN2_PERIOD {10.0} \
   CONFIG.MMCM_DIVCLK_DIVIDE {1} \
   CONFIG.PRIM_IN_FREQ {300.000} \
   CONFIG.PRIM_SOURCE {Differential_clock_capable_pin} \
   CONFIG.USE_PHASE_ALIGNMENT {true} \
   CONFIG.USE_RESET {false} \
 ] $clk_wiz_0

  # Create instance: xlconcat_1, and set properties
  set xlconcat_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_1 ]
  set_property -dict [ list \
   CONFIG.NUM_PORTS {5} \
 ] $xlconcat_1

  # Create instance: xlslice_0, and set properties
  set xlslice_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice xlslice_0 ]
  set_property -dict [ list \
   CONFIG.DIN_FROM {25} \
   CONFIG.DIN_TO {25} \
   CONFIG.DIN_WIDTH {26} \
   CONFIG.DOUT_WIDTH {1} \
 ] $xlslice_0

  # Create interface connections
  connect_bd_intf_net -intf_net CLK_IN [get_bd_intf_pins CLK_IN] [get_bd_intf_pins clk_wiz_0/CLK_IN1_D]

  # Create port connections
  connect_bd_net -net int0 [get_bd_pins int0] [get_bd_pins xlconcat_1/In0]
  connect_bd_net -net int1 [get_bd_pins int1] [get_bd_pins xlconcat_1/In1]
  connect_bd_net -net int2 [get_bd_pins int2] [get_bd_pins xlconcat_1/In2]
  connect_bd_net -net int3 [get_bd_pins int3] [get_bd_pins xlconcat_1/In3]
  connect_bd_net -net int4 [get_bd_pins int4] [get_bd_pins xlconcat_1/In4]
  connect_bd_net -net irq [get_bd_pins irq] [get_bd_pins xlconcat_1/dout]
  connect_bd_net -net pl_led [get_bd_pins pl_led] [get_bd_pins xlslice_0/Dout]
  
  # Internal connections
  connect_bd_net -net clk_wiz_0_clk_out1 [get_bd_pins clk_wiz_0/clk_out1] [get_bd_pins c_counter_binary_0/CLK]
  connect_bd_net -net clk_wiz_0_locked [get_bd_pins clk_wiz_0/locked] [get_bd_pins c_counter_binary_0/CE]
  connect_bd_net -net c_counter_binary_0_Q [get_bd_pins c_counter_binary_0/Q] [get_bd_pins xlslice_0/Din]


  # Restore current instance
  current_bd_instance $oldCurInst
}


###################################################################
#####  Top Level
###################################################################

# Create instance: APU_SS
create_hier_cell_APU_SS [current_bd_instance .] APU_SS

# Create instance: RPU_SS
create_hier_cell_RPU_SS [current_bd_instance .] RPU_SS

# Create instance: PL_SS
create_hier_cell_PL_SS [current_bd_instance .] PL_SS


# Create interface ports
set CLK_IN1_D [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:diff_clock_rtl:1.0 CLK_IN1_D ]
set_property -dict [ list \
 CONFIG.FREQ_HZ {300000000} \
 ] $CLK_IN1_D
set rpu_gpio [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 rpu_gpio ]
set apu_gpio [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 apu_gpio ]

# Create ports
set pl_led [ create_bd_port -dir O -from 0 -to 0 pl_led ]
set apu_led [ create_bd_port -dir O -from 0 -to 0 apu_led ]
set rpu_led [ create_bd_port -dir O -from 0 -to 0 rpu_led ]


###################################################################
#####  Top Level Connections
###################################################################

# Create interface connections
connect_bd_intf_net -intf_net APU_SS_M_AXI_FW1 [get_bd_intf_pins APU_SS/M_AXI_FW1] [get_bd_intf_pins zynq_ultra_ps_e_0/S_AXI_HP1_FPD]
connect_bd_intf_net -intf_net APU_SS_M_AXI_FW0 [get_bd_intf_pins APU_SS/M_AXI_FW0] [get_bd_intf_pins zynq_ultra_ps_e_0/S_AXI_HP0_FPD]
connect_bd_intf_net -intf_net RPU_SS_M_AXI [get_bd_intf_pins RPU_SS/M_AXI] [get_bd_intf_pins zynq_ultra_ps_e_0/S_AXI_LPD]
connect_bd_intf_net -intf_net CLK_IN1_D [get_bd_intf_ports CLK_IN1_D] [get_bd_intf_pins PL_SS/CLK_IN]
connect_bd_intf_net -intf_net RPU_SS_gpio [get_bd_intf_ports rpu_gpio] [get_bd_intf_pins RPU_SS/rpu_gpio]
connect_bd_intf_net -intf_net APU_SS_S00_AXI [get_bd_intf_pins APU_SS/S00_AXI] [get_bd_intf_pins zynq_ultra_ps_e_0/M_AXI_HPM0_FPD]
connect_bd_intf_net -intf_net APU_SS_APU_GPIO [get_bd_intf_ports apu_gpio] [get_bd_intf_pins APU_SS/apu_gpio]
connect_bd_intf_net -intf_net M_AXI_HPM0_LPD [get_bd_intf_pins RPU_SS/S00_AXI] [get_bd_intf_pins zynq_ultra_ps_e_0/M_AXI_HPM0_LPD]


# Connect the APU clock ports to the pl_clk0 clock
connect_bd_net [get_bd_pins zynq_ultra_ps_e_0/saxihp0_fpd_aclk] [get_bd_pins zynq_ultra_ps_e_0/pl_clk0]
connect_bd_net [get_bd_pins zynq_ultra_ps_e_0/saxihp1_fpd_aclk] [get_bd_pins zynq_ultra_ps_e_0/pl_clk0]
connect_bd_net [get_bd_pins zynq_ultra_ps_e_0/maxihpm0_fpd_aclk] [get_bd_pins zynq_ultra_ps_e_0/pl_clk0]
connect_bd_net [get_bd_pins APU_SS/clk] [get_bd_pins zynq_ultra_ps_e_0/pl_clk0]

# Connect the RPU clock ports to the pl_clk1 clock
connect_bd_net [get_bd_pins zynq_ultra_ps_e_0/maxihpm0_lpd_aclk] [get_bd_pins zynq_ultra_ps_e_0/pl_clk1]
connect_bd_net [get_bd_pins zynq_ultra_ps_e_0/saxi_lpd_aclk] [get_bd_pins zynq_ultra_ps_e_0/pl_clk1]
connect_bd_net [get_bd_pins RPU_SS/clk] [get_bd_pins zynq_ultra_ps_e_0/pl_clk1]

# Connect resets
connect_bd_net -net zynq_ultra_ps_e_0_pl_resetn0 [get_bd_pins APU_SS/pl_resetn] [get_bd_pins zynq_ultra_ps_e_0/pl_resetn0]
connect_bd_net -net zynq_ultra_ps_e_0_pl_resetn1 [get_bd_pins RPU_SS/pl_resetn] [get_bd_pins zynq_ultra_ps_e_0/pl_resetn1]


# Connect interrupts
connect_bd_net -net irqs [get_bd_pins PL_SS/irq] [get_bd_pins zynq_ultra_ps_e_0/pl_ps_irq0]
connect_bd_net -net axi_cdma_0_cdma_introut [get_bd_pins APU_SS/cdma_introut] [get_bd_pins PL_SS/int0]
connect_bd_net -net axi_dma_0_mm2s_introut [get_bd_pins APU_SS/mm2s_introut] [get_bd_pins PL_SS/int1]
connect_bd_net -net axi_dma_0_s2mm_introut [get_bd_pins APU_SS/s2mm_introut] [get_bd_pins PL_SS/int2]
connect_bd_net -net axi_dma_1_mm2s_introut [get_bd_pins RPU_SS/mm2s_introut] [get_bd_pins PL_SS/int3]
connect_bd_net -net axi_dma_1_s2mm_introut [get_bd_pins RPU_SS/s2mm_introut] [get_bd_pins PL_SS/int4]

# Connect misc signals
connect_bd_net -net pl_led [get_bd_ports pl_led] [get_bd_pins PL_SS/pl_led]
connect_bd_net -net apu_led [get_bd_ports apu_led] [get_bd_pins APU_SS/apu_led]
connect_bd_net -net rpu_led [get_bd_ports rpu_led] [get_bd_pins RPU_SS/rpu_led]
  

###################################################################
##### Setup isolation
###################################################################

set_property -dict [list CONFIG.PSU__PROTECTION__SUBSYSTEMS {APU:SD1;GEM3;APU;PCIe;Coresight;SATA1;USB0;DAP|RPU:Coresight;RPU0;DAP|APU_secure:SD1;APU|RPU1:Coresight;RPU1;DAP|PMU Firmware:PMU} CONFIG.PSU__PROTECTION__MASTERS_TZ {GEM0:NonSecure|SD1:Secure|GEM2:NonSecure|GEM1:NonSecure|GEM3:NonSecure|PCIe:NonSecure|DP:NonSecure|NAND:NonSecure|GPU:NonSecure|RPU1:Secure|RPU0:NonSecure|SATA0:NonSecure|SATA1:NonSecure|USB1:NonSecure|USB0:NonSecure|LDMA:NonSecure|FDMA:NonSecure|QSPI:NonSecure|SD0:NonSecure} CONFIG.PSU__PROTECTION__DDR_SEGMENTS {SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU|SA:0x0 ;SIZE:1;UNIT:MB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0x0 ;SIZE:1;UNIT:MB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU1} CONFIG.PSU__PROTECTION__OCM_SEGMENTS {SA:0xFFFC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure} CONFIG.PSU__PROTECTION__LPD_SEGMENTS {SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:256; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF070000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0E0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF020000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF170000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF150000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF110000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF120000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9D0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE200000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9B0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA10000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA30000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE000000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF380000; SIZE:512; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE100000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA60000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF980000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF410000; SIZE:640; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware|SA:0xFFE00000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFFE00000 ;SIZE:256;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF9A0000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF130000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF010000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF9A0000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU1|SA:0xFFE90000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU1|SA:0xFFEB0000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU1|SA:0xFF010000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU1} CONFIG.PSU__PROTECTION__FPD_SEGMENTS {SA:0xFD1A0000; SIZE:1280; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD000000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD010000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD020000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD030000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD040000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD050000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD610000; SIZE:512; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD5D0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware} CONFIG.PSU__PROTECTION__ENABLE {1}] [get_bd_cells zynq_ultra_ps_e_0]
set_property -dict [list CONFIG.PSU__PROTECTION__SUBSYSTEMS {APU:SD1;GEM3;APU;PCIe;Coresight;DAP|RPU:Coresight;S_AXI_LPD;RPU0;DAP|APU_secure:SD1;APU|RPU1:Coresight;RPU1;DAP|PMU Firmware:PMU} CONFIG.PSU__PROTECTION__MASTERS_TZ {GEM0:NonSecure|SD1:Secure|GEM2:NonSecure|GEM1:NonSecure|GEM3:NonSecure|PCIe:NonSecure|DP:NonSecure|NAND:NonSecure|GPU:NonSecure|RPU1:Secure|RPU0:NonSecure|SATA0:NonSecure|SATA1:NonSecure|USB1:NonSecure|USB0:NonSecure|LDMA:NonSecure|FDMA:NonSecure|QSPI:NonSecure|SD0:NonSecure} CONFIG.PSU__PROTECTION__DDR_SEGMENTS {SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1} CONFIG.PSU__PROTECTION__OCM_SEGMENTS {SA:0xFFFC0000; SIZE:256; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure} CONFIG.PSU__PROTECTION__LPD_SEGMENTS {SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF070000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0E0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF020000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF150000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF110000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF120000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9B0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA10000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA30000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE000000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF380000; SIZE:512; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE100000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA60000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFFE20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF130000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF980000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF410000; SIZE:640; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware|SA:0xFF050000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU} CONFIG.PSU__PROTECTION__FPD_SEGMENTS {SA:0xFD4D0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD1A0000; SIZE:1280; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD000000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD010000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD020000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD030000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD040000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD050000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD610000; SIZE:512; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD5D0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware}] [get_bd_cells zynq_ultra_ps_e_0]
set_property -dict [list CONFIG.PSU__PROTECTION__DDR_SEGMENTS {SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1} CONFIG.PSU__PROTECTION__OCM_SEGMENTS {SA:0xFFFC0000; SIZE:256; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure} CONFIG.PSU__PROTECTION__LPD_SEGMENTS {SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:256; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF070000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0E0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF020000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF170000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF150000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF110000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF120000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9D0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE200000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9B0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA10000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA30000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE000000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF380000; SIZE:512; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE100000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA60000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF130000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF980000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF410000; SIZE:640; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware|SA:0xFFE20000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU} CONFIG.PSU__PROTECTION__FPD_SEGMENTS {SA:0xFD1A0000; SIZE:1280; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD000000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD010000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD020000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD030000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD040000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD050000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD610000; SIZE:512; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD5D0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware}] [get_bd_cells zynq_ultra_ps_e_0]
set_property -dict [list CONFIG.PSU__PROTECTION__LPD_SEGMENTS {SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:256; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF070000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0E0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF020000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF170000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF150000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF110000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF120000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9D0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE200000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9B0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA10000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA30000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE000000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF380000; SIZE:512; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE100000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA60000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF130000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF980000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF410000; SIZE:640; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware|SA:0xFFE20000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF5E0000 ;SIZE:2560;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF5E0000 ;SIZE:2560;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU1}] [get_bd_cells zynq_ultra_ps_e_0]
set_property -dict [list CONFIG.PSU__PROTECTION__LPD_SEGMENTS {SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:256; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF070000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0E0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF020000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF170000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF150000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF110000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF120000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9D0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE200000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9B0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA10000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA30000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE000000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF380000; SIZE:512; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE100000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA60000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF130000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF980000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF410000; SIZE:640; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware|SA:0xFFE20000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF5E0000 ;SIZE:2560;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU|SA:0xFF5E0000 ;SIZE:2560;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:RPU1|SA:0xFF070000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF0E0000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF0A0000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF020000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF170000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF150000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF110000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF120000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF130000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF000000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF010000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFF9D0000 ;SIZE:64;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware|SA:0xFE200000 ;SIZE:1024;UNIT:KB ;RegionTZ:NonSecure ;WrAllowed:Read/Write;subsystemId:PMU Firmware}] [get_bd_cells zynq_ultra_ps_e_0]
set_property -dict [list CONFIG.PSU__PROTECTION__SUBSYSTEMS {APU:SD1;S_AXI_HP1_FPD;GEM3;APU;S_AXI_HP0_FPD;PCIe;Coresight;DAP|RPU:Coresight;S_AXI_LPD;RPU0;DAP|APU_secure:SD1;APU|RPU1:Coresight;RPU1;DAP|PMU Firmware:PMU} CONFIG.PSU__PROTECTION__MASTERS_TZ {GEM0:NonSecure|SD1:Secure|GEM2:NonSecure|GEM1:NonSecure|GEM3:NonSecure|PCIe:NonSecure|DP:NonSecure|NAND:NonSecure|GPU:NonSecure|RPU1:Secure|RPU0:NonSecure|SATA0:NonSecure|SATA1:NonSecure|USB1:NonSecure|USB0:NonSecure|LDMA:NonSecure|FDMA:NonSecure|QSPI:NonSecure|SD0:NonSecure}] [get_bd_cells zynq_ultra_ps_e_0]
set_property -dict [list CONFIG.PSU__PROTECTION__SUBSYSTEMS {APU:SD1;S_AXI_HP1_FPD;GEM3;APU;S_AXI_HP0_FPD;PCIe;Coresight;DAP|RPU:Coresight;S_AXI_LPD;RPU0;DAP|APU_secure:SD1;APU|RPU1:Coresight;S_AXI_LPD;RPU1;DAP|PMU Firmware:PMU} CONFIG.PSU__PROTECTION__MASTERS_TZ {GEM0:NonSecure|SD1:Secure|GEM2:NonSecure|GEM1:NonSecure|GEM3:NonSecure|PCIe:NonSecure|DP:NonSecure|NAND:NonSecure|GPU:NonSecure|RPU1:Secure|RPU0:NonSecure|SATA0:NonSecure|SATA1:NonSecure|USB1:NonSecure|USB0:NonSecure|LDMA:NonSecure|FDMA:NonSecure|QSPI:NonSecure|SD0:NonSecure}] [get_bd_cells zynq_ultra_ps_e_0]
set_property -dict [list CONFIG.PSU__PROTECTION__DDR_SEGMENTS {SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0x800000000; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0x800000000; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0x0; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0x800000000; SIZE:2; UNIT:GB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1} CONFIG.PSU__PROTECTION__OCM_SEGMENTS {SA:0xFFFC0000; SIZE:256; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure} CONFIG.PSU__PROTECTION__LPD_SEGMENTS {SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:256; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF070000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0E0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF0A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF020000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF170000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF150000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF110000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF120000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9D0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE200000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9B0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA10000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA30000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE000000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF380000; SIZE:512; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFE100000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFA60000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:APU| SA:0xFFE00000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFFE20000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF130000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:APU_secure| SA:0xFFE90000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFFEB0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:RPU1| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF070000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF0E0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF0A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF020000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF170000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF150000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF110000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF120000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF130000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF000000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF010000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF9D0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFE200000; SIZE:1024; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF980000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF5E0000; SIZE:2560; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFCC0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF180000; SIZE:768; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF410000; SIZE:640; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA70000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFF9A0000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFFA50000; SIZE:64; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFE800000; SIZE:8192; UNIT:KB; RegionTZ:NonSecure; WrAllowed:Read/Write; subsystemId:PMU Firmware} CONFIG.PSU__PROTECTION__FPD_SEGMENTS {SA:0xFD1A0000; SIZE:1280; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD000000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD010000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD020000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD030000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD040000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD050000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD610000; SIZE:512; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware| SA:0xFD5D0000; SIZE:64; UNIT:KB; RegionTZ:Secure; WrAllowed:Read/Write; subsystemId:PMU Firmware}] [get_bd_cells zynq_ultra_ps_e_0]

###################################################################
##### Setup address map
###################################################################

# Create address segments
assign_bd_address


# Get rid of critical warnings about OCM being excluded from every master
delete_bd_objs [get_bd_addr_segs -excluded APU_SS/APU_SS_masters/axi_cdma_0/Data_SG/SEG_zynq_ultra_ps_e_0_HP0_LPS_OCM]
delete_bd_objs [get_bd_addr_segs -excluded APU_SS/APU_SS_masters/axi_cdma_0/Data/SEG_zynq_ultra_ps_e_0_HP0_LPS_OCM]
delete_bd_objs [get_bd_addr_segs -excluded APU_SS/APU_SS_masters/axi_dma_0/Data_SG/SEG_zynq_ultra_ps_e_0_HP1_LPS_OCM]
delete_bd_objs [get_bd_addr_segs -excluded APU_SS/APU_SS_masters/axi_dma_0/Data_MM2S/SEG_zynq_ultra_ps_e_0_HP1_LPS_OCM]
delete_bd_objs [get_bd_addr_segs -excluded APU_SS/APU_SS_masters/axi_dma_0/Data_S2MM/SEG_zynq_ultra_ps_e_0_HP1_LPS_OCM]
delete_bd_objs [get_bd_addr_segs -excluded RPU_SS/RPU_SS_masters/axi_dma_1/Data_S2MM/SEG_zynq_ultra_ps_e_0_LPD_LPS_OCM]
delete_bd_objs [get_bd_addr_segs -excluded RPU_SS/RPU_SS_masters/axi_dma_1/Data_SG/SEG_zynq_ultra_ps_e_0_LPD_LPS_OCM]
delete_bd_objs [get_bd_addr_segs -excluded RPU_SS/RPU_SS_masters/axi_dma_1/Data_MM2S/SEG_zynq_ultra_ps_e_0_LPD_LPS_OCM]

###################################################################
#####  Create Wrapper
###################################################################

make_wrapper -files [get_files xilinx-zcu102-v2018.3/xilinx-zcu102-v2018.3.srcs/sources_1/bd/design_1/design_1.bd] -top
add_files -norecurse xilinx-zcu102-v2018.3/xilinx-zcu102-v2018.3.srcs/sources_1/bd/design_1/hdl/design_1_wrapper.v

###################################################################
#####  Add Constraints
###################################################################

add_files -fileset constrs_1 -norecurse subsystem_design_top.xdc

